/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.DirtyFlagProvider");

//<INTERFACE>
/**
 * Base interface that allows to track whether a node or model has been modified (i.e. became dirty).
 *
 * @since 3.0.0.1
 * @ibm-spi
 * @ibm-module Base
 */
dojo.declare("com.ibm.mashups.enabler.DirtyFlagProvider", null, {

    /**
     * Tests whether the instance is dirty. Instances that have been modified, or newly created return true.
     * 
     * @return {Boolean} true if the instance is dirty, otherwise false.
     */
    isDirty: function() {},

    /**
     * Marks this instance as dirty.
     */
    setDirty: function() {},

    /**
     * Marks this instance as not dirty, i.e. clean.
     */
    setClean: function() {},

    /**
     * Adds a callback handler to be called when the instance changes its state.
     * 
     * @param {Object} ctx The context in which to run the callback handler
     * Must not be <code>null</code>
     * @param {Object} callback the callback funtion in the format of <code>Function(Object[] passed in with addDirtyCallback)</code>. 
     * Must not be <code>null</code>
     * @param {Object[]} parameters optional array of parameters to be
     * passed on to the callback function. May be <code>null</code>
     * @param {Boolean} alwaysFire Specifies whether to only fire when clean->dirty (set flag to false) or also fire when dirty->dirty (set flag to true)
     */
    addDirtyCallback: function(ctx, callback, parameters, alwaysFire) {
    },
    
    /**
     * Removes a callback handler previously added
     * 
     * @param {Object} callback the callback funtion to be removed. 
     * Must not be <code>null</code>
     */
    removeDirtyCallback: function(fn){
    }

});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.DirtyFlagProviderImpl");
